/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.server.plugin;

import java.util.Collection;

import org.apache.qpid.server.model.ConfiguredObjectInjectedAttribute;
import org.apache.qpid.server.model.ConfiguredObjectInjectedOperation;
import org.apache.qpid.server.model.ConfiguredObjectInjectedStatistic;
import org.apache.qpid.server.model.InjectedAttributeStatisticOrOperation;

public interface ConfiguredObjectAttributeInjector extends Pluggable
{
    Collection<ConfiguredObjectInjectedAttribute<?,?>> getInjectedAttributes();
    Collection<ConfiguredObjectInjectedStatistic<?,?>> getInjectedStatistics();
    Collection<ConfiguredObjectInjectedOperation<?>> getInjectedOperations();

    default InjectedAttributeStatisticOrOperation.TypeValidator getTypeValidator()
    {
        return type -> true;
    }
}
